summaryrefslogtreecommitdiffstats
path: root/kdejava/koala/org/kde/koala/BrowserExtensionSignals.java
diff options
context:
space:
mode:
Diffstat (limited to 'kdejava/koala/org/kde/koala/BrowserExtensionSignals.java')
-rw-r--r--kdejava/koala/org/kde/koala/BrowserExtensionSignals.java26
1 files changed, 13 insertions, 13 deletions
diff --git a/kdejava/koala/org/kde/koala/BrowserExtensionSignals.java b/kdejava/koala/org/kde/koala/BrowserExtensionSignals.java
index 7c11b38e..9a7f993d 100644
--- a/kdejava/koala/org/kde/koala/BrowserExtensionSignals.java
+++ b/kdejava/koala/org/kde/koala/BrowserExtensionSignals.java
@@ -1,11 +1,11 @@
//Auto-generated by kalyptus. DO NOT EDIT.
package org.kde.koala;
-import org.kde.qt.QMetaObject;
+import org.kde.qt.TQMetaObject;
import org.kde.qt.QtSupport;
-import org.kde.qt.QObject;
-import org.kde.qt.QDataStream;
-import org.kde.qt.QPoint;
+import org.kde.qt.TQObject;
+import org.kde.qt.TQDataStream;
+import org.kde.qt.TQPoint;
import java.util.ArrayList;
public interface BrowserExtensionSignals {
@@ -117,15 +117,15 @@ public interface BrowserExtensionSignals {
at the point <code>global</code> for the files <code>items.</code>
@short Emit this to make the browser show a standard popup menu at the point <code>global</code> for the files <code>items.</code>
*/
- void popupMenu(QPoint global, ArrayList items);
+ void popupMenu(TQPoint global, ArrayList items);
/**
Emit this to make the browser show a standard popup menu
at the point <code>global</code> for the files <code>items.</code>
The GUI described by <code>client</code> is being merged with the popupmenu of the host
@short Emit this to make the browser show a standard popup menu at the point <code>global</code> for the files <code>items.</code>
*/
- void popupMenu(KXMLGUIClientInterface client, QPoint global, ArrayList items);
- // void popupMenu(KXMLGUIClient* arg1,const QPoint& arg2,const KFileItemList& arg3,const KParts::URLArgs& arg4,KParts::BrowserExtension::PopupFlags arg5); >>>> NOT CONVERTED
+ void popupMenu(KXMLGUIClientInterface client, TQPoint global, ArrayList items);
+ // void popupMenu(KXMLGUIClient* arg1,const TQPoint& arg2,const KFileItemList& arg3,const KParts::URLArgs& arg4,KParts::BrowserExtension::PopupFlags arg5); >>>> NOT CONVERTED
/**
Emit this to make the browser show a standard popup menu
at the point <code>global</code> for the given <code>url.</code>
@@ -134,7 +134,7 @@ public interface BrowserExtensionSignals {
(<code>mode</code>: S_IFREG, S_IFDIR...)
@short Emit this to make the browser show a standard popup menu at the point <code>global</code> for the given <code>url.</code>
*/
- void popupMenu(QPoint global, KURL url, String mimeType, long mode);
+ void popupMenu(TQPoint global, KURL url, String mimeType, long mode);
/**
Emit this to make the browser show a standard popup menu
at the point <code>global</code> for the given <code>url.</code>
@@ -143,7 +143,7 @@ public interface BrowserExtensionSignals {
(<code>mode</code>: S_IFREG, S_IFDIR...)
@short Emit this to make the browser show a standard popup menu at the point <code>global</code> for the given <code>url.</code>
*/
- void popupMenu(QPoint global, KURL url, String mimeType);
+ void popupMenu(TQPoint global, KURL url, String mimeType);
/**
Emit this to make the browser show a standard popup menu
at the point <code>global</code> for the given <code>url.</code>
@@ -153,7 +153,7 @@ public interface BrowserExtensionSignals {
The GUI described by <code>client</code> is being merged with the popupmenu of the host
@short Emit this to make the browser show a standard popup menu at the point <code>global</code> for the given <code>url.</code>
*/
- void popupMenu(KXMLGUIClientInterface client, QPoint global, KURL url, String mimeType, long mode);
+ void popupMenu(KXMLGUIClientInterface client, TQPoint global, KURL url, String mimeType, long mode);
/**
Emit this to make the browser show a standard popup menu
at the point <code>global</code> for the given <code>url.</code>
@@ -163,9 +163,9 @@ public interface BrowserExtensionSignals {
The GUI described by <code>client</code> is being merged with the popupmenu of the host
@short Emit this to make the browser show a standard popup menu at the point <code>global</code> for the given <code>url.</code>
*/
- void popupMenu(KXMLGUIClientInterface client, QPoint global, KURL url, String mimeType);
- // void popupMenu(KXMLGUIClient* arg1,const QPoint& arg2,const KURL& arg3,const KParts::URLArgs& arg4,KParts::BrowserExtension::PopupFlags arg5,mode_t arg6); >>>> NOT CONVERTED
- // void popupMenu(KXMLGUIClient* arg1,const QPoint& arg2,const KURL& arg3,const KParts::URLArgs& arg4,KParts::BrowserExtension::PopupFlags arg5); >>>> NOT CONVERTED
+ void popupMenu(KXMLGUIClientInterface client, TQPoint global, KURL url, String mimeType);
+ // void popupMenu(KXMLGUIClient* arg1,const TQPoint& arg2,const KURL& arg3,const KParts::URLArgs& arg4,KParts::BrowserExtension::PopupFlags arg5,mode_t arg6); >>>> NOT CONVERTED
+ // void popupMenu(KXMLGUIClient* arg1,const TQPoint& arg2,const KURL& arg3,const KParts::URLArgs& arg4,KParts::BrowserExtension::PopupFlags arg5); >>>> NOT CONVERTED
/**
Inform the hosting application about the current selection.
Used when a set of files/URLs is selected (with full information